aboutsummaryrefslogtreecommitdiff
path: root/src/bullets.s
diff options
context:
space:
mode:
Diffstat (limited to 'src/bullets.s')
-rw-r--r--src/bullets.s3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/bullets.s b/src/bullets.s
index 3cc74b9..802edb7 100644
--- a/src/bullets.s
+++ b/src/bullets.s
@@ -297,8 +297,9 @@
jsr Enemies::collides
beq @next_enemy_collision
;; Yes! Kill the enemy and break the loop.
jsr Enemies::bite_the_dust
+ ADD_ENEMY_SCORE
jmp @save_bullet_move
@next_enemy_collision:
@@ -297,8 +297,9 @@
jsr Enemies::collides
beq @next_enemy_collision
- ;; Yes! Kill the enemy and break the loop.
+ ;; Yes! Kill the enemy, keep the score and break the loop.
jsr Enemies::bite_the_dust